@@ -3,11 +3,11 @@
  */
 
 @interface NSObject (OC_Comparison)
--(NSComparisonResult)compare:(NSObject*)other;
+- (NSComparisonResult)compare:(NSObject*)other;
 @end
 
-
-static const void *mod_binheap_retain (CFAllocatorRef allocator __attribute__((__unused__)), const void *ptr)
+static const void*
+mod_binheap_retain(CFAllocatorRef allocator __attribute__((__unused__)), const void* ptr)
 {
     if (ptr) {
         CFRetain(ptr);
@@ -15,38 +15,35 @@ static const void *mod_binheap_retain (CFAllocatorRef allocator __attribute__((_
     return ptr;
 }
 
-static void mod_binheap_release (CFAllocatorRef allocator __attribute__((__unused__)), const void *ptr)
+static void
+mod_binheap_release(CFAllocatorRef allocator __attribute__((__unused__)), const void* ptr)
 {
     if (ptr) {
         CFRelease(ptr);
     }
 }
 
-static CFStringRef mod_binheap_copydescription(const void* ptr)
+static CFStringRef
+mod_binheap_copydescription(const void* ptr)
 {
     CFStringRef r = CFCopyDescription(ptr);
     return r;
 }
 
-CFComparisonResult mod_binheap_compare(const void *ptr1, const void *ptr2, void *info __attribute__((__unused__)))
+CFComparisonResult
+mod_binheap_compare(const void* ptr1, const void* ptr2,
+                    void* info __attribute__((__unused__)))
 {
     NSObject* o1 = (NSObject*)ptr1;
     NSObject* o2 = (NSObject*)ptr2;
 
-
     NSComparisonResult result = [o1 compare:o2];
     return (CFComparisonResult)result;
 }
 
-
 static CFBinaryHeapCallBacks mod_NSObjectBinaryHeapCallbacks = {
-    0,
-    mod_binheap_retain,
-    mod_binheap_release,
-    mod_binheap_copydescription,
-    mod_binheap_compare
-};
-
+    0, mod_binheap_retain, mod_binheap_release, mod_binheap_copydescription,
+    mod_binheap_compare};
 
 static PyObject*
 mod_CFBinaryHeapCreate(PyObject* self __attribute__((__unused__)), PyObject* args)
@@ -56,7 +53,6 @@ mod_CFBinaryHeapCreate(PyObject* self __attribute__((__unused__)), PyObject* arg
     CFAllocatorRef allocator;
     CFBinaryHeapRef heap;
 
-
     if (!PyArg_ParseTuple(args, "On", &py_allocator, &count)) {
         return NULL;
     }
@@ -74,16 +70,12 @@ mod_CFBinaryHeapCreate(PyObject* self __attribute__((__unused__)), PyObject* arg
     return result;
 }
 
-
 static PyObject*
-mod_CFBinaryHeapGetValues(
-    PyObject* self __attribute__((__unused__)),
-    PyObject* args)
+mod_CFBinaryHeapGetValues(PyObject* self __attribute__((__unused__)), PyObject* args)
 {
     PyObject* py_heap;
     CFBinaryHeapRef heap;
 
-
     if (!PyArg_ParseTuple(args, "O", &py_heap)) {
         return NULL;
     }
@@ -101,21 +93,13 @@ mod_CFBinaryHeapGetValues(
     memset(members, 0, sizeof(NSObject*) * count);
 
     CFBinaryHeapGetValues(heap, (const void**)members);
-    PyObject* result = PyObjC_CArrayToPython(@encode(NSObject*), members, (Py_ssize_t)count);
+    PyObject* result =
+        PyObjC_CArrayToPython(@encode(NSObject*), members, (Py_ssize_t)count);
     free(members);
     return result;
 }
 
-#define COREFOUNDATION_CFBINARYHEAP_METHODS \
-    { \
-        "CFBinaryHeapCreate", \
-        (PyCFunction)mod_CFBinaryHeapCreate, \
-        METH_VARARGS, \
-        NULL \
-    }, \
-    { \
-        "CFBinaryHeapGetValues", \
-        (PyCFunction)mod_CFBinaryHeapGetValues, \
-        METH_VARARGS, \
-        NULL \
-    },
+#define COREFOUNDATION_CFBINARYHEAP_METHODS                                              \
+    {"CFBinaryHeapCreate", (PyCFunction)mod_CFBinaryHeapCreate, METH_VARARGS, NULL},     \
+        {"CFBinaryHeapGetValues", (PyCFunction)mod_CFBinaryHeapGetValues, METH_VARARGS,  \
+         NULL},
